**prEN 1995-1-1 - September 2023
Eurocode 5: Design of Timber structures
Part 1-1: General rules and rules for building**

The table presents a list of tables from the Eurocode 5 standards for timber structures, tracking their implementation status (:x: or :heavy_check_mark:) and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 0 tables present.

| Table number | Done | Remarks | Object name |
|:-------------|:----:|:--------|:------------|
